@@ -264,6 +264,20 @@ def test_overlap():
     assert g.chunks == ((8, 8), (5, 5))
 
 
+def test_overlap_allow_rechunk_kwarg():
+    # The smallest array chunk is too small to fit overlap depth
+    arr = da.arange(6, chunks=5)
+    da.overlap.overlap(arr, 2, "reflect", allow_rechunk=True)
+    arr.map_overlap(lambda x: x, 2, "reflect", allow_rechunk=True)
+    with pytest.raises(ValueError):
+        da.overlap.overlap(arr, 2, "reflect", allow_rechunk=False)
+    with pytest.raises(ValueError):
+        arr.map_overlap(lambda x: x, 2, "reflect", allow_rechunk=False)
+    # No rechunking required
+    arr = da.arange(6, chunks=4)
+    da.overlap.overlap(arr, 2, "reflect", allow_rechunk=False)
+
+
 def test_asymmetric_overlap_boundary_exception():
     x = da.arange(10, chunks=5)
     with pytest.raises(NotImplementedError):
