@@ -3,7 +3,8 @@ Control global computation context
 """
 import threading
 from functools import partial
-from . import config
+
+from dask import config
 
 _globals = config.config
 
