@@ -7,7 +7,11 @@ import pytest
 from pandas.api.types import is_scalar
 
 import dask.dataframe as dd
-from dask.dataframe._compat import PANDAS_GT_120, PANDAS_VERSION
+from dask.dataframe._compat import (
+    PANDAS_GT_120,
+    PANDAS_VERSION,
+    check_numeric_only_deprecation,
+)
 from dask.dataframe.utils import assert_dask_graph, assert_eq, make_meta
 
 try:
@@ -636,7 +640,7 @@ def test_frame_series_arithmetic_methods():
         assert_eq(l.rmod(r, axis=0), el.rmod(er, axis=0))
         assert_eq(l.rpow(r, axis=0), el.rpow(er, axis=0))
 
-        pytest.raises(ValueError, lambda: l.add(r, axis=1))
+        pytest.raises(ValueError, lambda l=l, r=r: l.add(r, axis=1))
 
     for l, r, el, er in [(ddf1, pdf2, pdf1, pdf2), (ddf1, ps3, pdf1, ps3)]:
         assert_eq(l, el)
@@ -967,17 +971,17 @@ def test_reduction_series_invalid_axis():
 
     for axis in [1, "columns"]:
         for s in [ddf1.a, pdf1.a]:  # both must behave the same
-            pytest.raises(ValueError, lambda: s.sum(axis=axis))
-            pytest.raises(ValueError, lambda: s.prod(axis=axis))
-            pytest.raises(ValueError, lambda: s.product(axis=axis))
-            pytest.raises(ValueError, lambda: s.min(axis=axis))
-            pytest.raises(ValueError, lambda: s.max(axis=axis))
+            pytest.raises(ValueError, lambda s=s, axis=axis: s.sum(axis=axis))
+            pytest.raises(ValueError, lambda s=s, axis=axis: s.prod(axis=axis))
+            pytest.raises(ValueError, lambda s=s, axis=axis: s.product(axis=axis))
+            pytest.raises(ValueError, lambda s=s, axis=axis: s.min(axis=axis))
+            pytest.raises(ValueError, lambda s=s, axis=axis: s.max(axis=axis))
             # only count doesn't have axis keyword
-            pytest.raises(TypeError, lambda: s.count(axis=axis))
-            pytest.raises(ValueError, lambda: s.std(axis=axis))
-            pytest.raises(ValueError, lambda: s.var(axis=axis))
-            pytest.raises(ValueError, lambda: s.sem(axis=axis))
-            pytest.raises(ValueError, lambda: s.mean(axis=axis))
+            pytest.raises(TypeError, lambda s=s, axis=axis: s.count(axis=axis))
+            pytest.raises(ValueError, lambda s=s, axis=axis: s.std(axis=axis))
+            pytest.raises(ValueError, lambda s=s, axis=axis: s.var(axis=axis))
+            pytest.raises(ValueError, lambda s=s, axis=axis: s.sem(axis=axis))
+            pytest.raises(ValueError, lambda s=s, axis=axis: s.mean(axis=axis))
 
 
 def test_reductions_non_numeric_dtypes():
@@ -1161,27 +1165,51 @@ def test_reductions_frame_dtypes():
     ddf_no_timedelta = dd.from_pandas(df_no_timedelta, 3)
 
     assert_eq(df.drop(columns="dt").sum(), ddf.drop(columns="dt").sum())
+    with check_numeric_only_deprecation():
+        expected = df_no_timedelta.drop(columns="dt").mean()
     assert_eq(
-        df_no_timedelta.drop(columns="dt").mean(),
+        expected,
         ddf_no_timedelta.drop(columns="dt").mean(),
     )
 
-    assert_eq(df.prod(), ddf.prod())
-    assert_eq(df.product(), ddf.product())
+    with check_numeric_only_deprecation():
+        expected = df.prod()
+    assert_eq(expected, ddf.prod())
+    with check_numeric_only_deprecation():
+        expected = df.product()
+    assert_eq(expected, ddf.product())
     assert_eq(df.min(), ddf.min())
     assert_eq(df.max(), ddf.max())
     assert_eq(df.count(), ddf.count())
-    assert_eq(df.sem(), ddf.sem())
-    assert_eq(df.sem(ddof=0), ddf.sem(ddof=0))
+    with check_numeric_only_deprecation():
+        expected = df.sem()
+    assert_eq(expected, ddf.sem())
+    with check_numeric_only_deprecation():
+        expected = df.sem(ddof=0)
+    assert_eq(expected, ddf.sem(ddof=0))
 
-    assert_eq(df_no_timedelta.std(), ddf_no_timedelta.std())
-    assert_eq(df_no_timedelta.std(skipna=False), ddf_no_timedelta.std(skipna=False))
-    assert_eq(df_no_timedelta.std(ddof=0), ddf_no_timedelta.std(ddof=0))
-    assert_eq(df_no_timedelta.var(), ddf_no_timedelta.var())
-    assert_eq(df_no_timedelta.var(skipna=False), ddf_no_timedelta.var(skipna=False))
-    assert_eq(df_no_timedelta.var(ddof=0), ddf_no_timedelta.var(ddof=0))
+    with check_numeric_only_deprecation():
+        expected = df_no_timedelta.std()
+    assert_eq(expected, ddf_no_timedelta.std())
+    with check_numeric_only_deprecation():
+        expected = df_no_timedelta.std(skipna=False)
+    assert_eq(expected, ddf_no_timedelta.std(skipna=False))
+    with check_numeric_only_deprecation():
+        expected = df_no_timedelta.std(ddof=0)
+    assert_eq(expected, ddf_no_timedelta.std(ddof=0))
+    with check_numeric_only_deprecation():
+        expected = df_no_timedelta.var()
+    assert_eq(expected, ddf_no_timedelta.var())
+    with check_numeric_only_deprecation():
+        expected = df_no_timedelta.var(skipna=False)
+    assert_eq(expected, ddf_no_timedelta.var(skipna=False))
+    with check_numeric_only_deprecation():
+        expected = df_no_timedelta.var(ddof=0)
+    assert_eq(expected, ddf_no_timedelta.var(ddof=0))
+    with check_numeric_only_deprecation():
+        expected = df_no_timedelta.var(ddof=0, skipna=False)
     assert_eq(
-        df_no_timedelta.var(ddof=0, skipna=False),
+        expected,
         ddf_no_timedelta.var(ddof=0, skipna=False),
     )
 
@@ -1195,8 +1223,12 @@ def test_reductions_frame_dtypes():
     # only timedelta
     df_td = df[["timedelta"]]
     ddf_td = dd.from_pandas(df_td, 3)
-    assert_eq(df_td.var(ddof=0), ddf_td.var(ddof=0))
-    assert_eq(df_td.var(), ddf_td.var())
+    with check_numeric_only_deprecation():
+        expected = df_td.var(ddof=0)
+    assert_eq(expected, ddf_td.var(ddof=0))
+    with check_numeric_only_deprecation():
+        expected = df_td.var()
+    assert_eq(expected, ddf_td.var())
 
     # only numercis
     df_numerics = df[["int", "float", "bool"]]
