@@ -10,6 +10,7 @@ from operator import getitem
 from distributed import Client, SchedulerPlugin
 from distributed.utils_test import cluster, loop  # noqa F401
 
+from dask.highlevelgraph import HighLevelGraph
 from dask.layers import ArrayChunkShapeDep, ArraySliceDep, fractional_slice
 
 
@@ -243,6 +244,7 @@ def test_dataframe_cull_key_dependencies(op):
     # "complex" DataFrame Layers
     # See: https://github.com/dask/dask/pull/9267
 
+    pytest.importorskip("dask.dataframe")
     datasets = pytest.importorskip("dask.datasets")
 
     result = op(datasets.timeseries(end="2000-01-15")).count()
@@ -250,3 +252,45 @@ def test_dataframe_cull_key_dependencies(op):
     culled_graph = graph.cull(result.__dask_keys__())
 
     assert graph.get_all_dependencies() == culled_graph.get_all_dependencies()
+
+
+def test_dataframe_cull_key_dependencies_materialized():
+    # Test that caching of MaterializedLayer
+    # dependencies during culling doesn't break
+    # the result of ``get_all_dependencies``
+
+    datasets = pytest.importorskip("dask.datasets")
+    dd = pytest.importorskip("dask.dataframe")
+
+    ddf = datasets.timeseries(end="2000-01-15")
+
+    # Build a custom layer to ensure
+    # MaterializedLayer is used
+    name = "custom_graph_test"
+    name_0 = "custom_graph_test_0"
+    dsk = {}
+    for i in range(ddf.npartitions):
+        dsk[(name_0, i)] = (lambda x: x, (ddf._name, i))
+        dsk[(name, i)] = (lambda x: x, (name_0, i))
+    dsk = HighLevelGraph.from_collections(name, dsk, dependencies=[ddf])
+    result = dd.core.new_dd_object(dsk, name, ddf._meta, ddf.divisions)
+    graph = result.dask
+
+    # HLG cull
+    culled_keys = [k for k in result.__dask_keys__() if k != (name, 0)]
+    culled_graph = graph.cull(culled_keys)
+
+    # Check that culled_deps are cached
+    # See: https://github.com/dask/dask/issues/9389
+    cached_deps = culled_graph.key_dependencies.copy()
+    deps = culled_graph.get_all_dependencies()
+    assert cached_deps == deps
+
+    # Manual cull
+    deps0 = graph.get_all_dependencies()
+    deps0.pop((name, 0))
+    deps0.pop((name_0, 0))
+    deps0.pop((ddf._name, 0))
+
+    # Check that get_all_dependencies results match
+    assert deps0 == deps
